.TH AFDPJOIN 1 "" "AFDP 0.98"
.SH NAME
afdpjoin - subscribe to an AFDP group
.SH SYNOPSIS
.B afdpjoin
[
.B \-DVdhr
]
[
.B \-a
.I aclfile
]
[
.B \-g
.I group_number
]
[
.B \-p
.I port
]
[
.B -s
.I secretary_host
]
[
.B \-c
.I safe_command
]
[
.B \-o
.I nowait
]
[
.B \-I
]
[
.B \-T
.I threshold
]
[
.B \-t
.I ttl
]
.SH DESCRIPTION
.PP
.I afdpjoin
first tries to locate an AFDP secretary for the requested group (default
group id = 1). If a secretary_host is given on the command line, that
host is queried to find the secretary. If not, broadcast is used to 
locate a secretary on the local network.
If a secretary isn't specified, or is the same as the local host
afdpjoin is running on, the current process will become the secretary
if one cannot be found.
If a specified secretary can't be located, afdpjoin exits with status 1.
.PP
If becoming a secretary, the local process binds to the afdp search port,
so it can respond to FIND_SECRETARY requests.
.PP
If a remote secretary is found, afdpjoin asks for permission to join
the group, and is given the group_data_port on which to listen 
for file transfers.
.SH OPTIONS
.TP 8
.B \-D
Enable daemon mode. All messages will be sent via syslog() instead of being
written to stderr.
Also disables the run-time commands
by not doing a select on fileno(stdin),
so that afdpjoin can be run without a controlling tty.
.TP 8
.B \-V
Print version information for the program, and exit with status 3.
.TP 8
.BI \-a " aclfile"
Use the given aclfile, for the access control lists.
.TP 8
.B \-d
Increment debug level by one.
The debug level starts at zero (report errors only), and more detailed
messages are given as the level increases.
.TP 8
.BI \-g " group"
The numeric group ID (default=1).
.TP 8
.B \-h
A help message is printed, and afdpjoin exits with status 2.
.TP 8
.BI \-p " port"
Use the given port for FIND_SECRETARY messages.
Port may be a number, or a service name as listed in /etc/services.
.TP 8
.B \-r
Use reserved ports (root only).
.TP 8
.BI \-s " secretary"
Hostname of secretary host to use.
If no '-s' option is given, the local network will be searched for
a secretary using broadcast packets.
.TP 8
.BI \-c " safe_command"
Sets the command to be run after receipt of each file.
For security reasons, you may not want the publisher to be able
to cause commands to be run on the subscribers.
.TP 8
.BI \-o " nowait"
Disables the random_wait feature of the AFDP protocol,
which helps prevent subscribers from over-running the publisher
with resend requests if a packet was dropped.
.TP 8
.BI \-I
Set 'Internet' mode. This sets the threshold to a very large value,
so that broadcast is never used.
File transfers will use unicast, unless all participating
hosts support multicast in which case that will be used instead.
.TP 8
.BI \-T " threshold"
The number of hosts in the group at which the transmit mode should
switch from unicast to broadcast, to lessen network loading (default = 3).
.TP 8
.BI \-t " ttl"
Sets the ttl that is used in multicast packets, to allow for use 
over an internetwork (default = 1, which prevents routing of packets).
.SH "RUN-TIME COMMANDS"
.TP 8
.B \+
Increment debug level by one.
.TP 8
.B \-
Decrement debug level by one.
.TP 8
.B \q
Leave group (quit subscriber functions, but remain as secretary).
.TP 8
.B \Q
Shutdown group, causes all subscribers and publishers to quit,
then secretary quits.
.SH "EXAMPLES"
.TP
afdpjoin -d -g 40
Join afdp group 40 on local network.
Show level-one debug messages.
If no secretary is found, local host will assume secretary duties.
.TP
afdpjoin -d -d -g 55 -s stealth.ecf -I
Join afdp group 55 on stealth.ecf.
Show level-two debug messages (more detailed).
If no secretary is found on stealth.ecf, exit with an error code,
unless we ARE on stealth.ecf, in which case we will become the secretary.
Also set Internet mode, which prevents using broadcast transport.
.SH "SEE ALSO"
afdpsend(1)
.SH DIAGNOSTICS
Exit status of 0 indicates normal status, 1 if secretary cannot
be found, 2 for syntax errors, 3 for unimplemented option,
5 for system call failures, 4 for other errors.
.SH "BUGS"
.PP
Should use multicast, with ttl>1 to search neighbouring networks for secretary.
.PP
Quit does not work on an internetwork yet, because it uses broadcast.
.SH COPYRIGHT
Copyright (c) 1994, 1995  by Jeremy Cooperstock and Steve Kotsopoulos,
All Rights Reserved.
.SH AUTHORS
Jeremy Cooperstock <jer@dgp.toronto.edu> and
Steve Kotsopoulos <steve@ecf.toronto.edu>, University of Toronto.
